pub enum WorkerServiceCallback<T, Payload>{
OnlyRequest(Box<dyn FnMut(&mut Payload, T::Request) -> T::Response + Send>),
WithId(Box<dyn FnMut(&mut Payload, T::Request, RequestId) -> T::Response + Send>),
WithInfo(Box<dyn FnMut(&mut Payload, T::Request, ServiceInfo) -> T::Response + Send>),
}Expand description
An enum capturing the various possible function signatures for service
callbacks that can be used by a Worker.
The correct enum variant is deduced by the IntoWorkerServiceCallback trait.
Variants
OnlyRequest(Box<dyn FnMut(&mut Payload, T::Request) -> T::Response + Send>)
A callback that only takes in the request value
WithId(Box<dyn FnMut(&mut Payload, T::Request, RequestId) -> T::Response + Send>)
A callback that takes in the request value and the ID of the request
WithInfo(Box<dyn FnMut(&mut Payload, T::Request, ServiceInfo) -> T::Response + Send>)
A callback that takes in the request value and all available