ResultClient

Struct ResultClient 

pub struct ResultClient<A: Action> { /* private fields */ }
This struct allows you to receive the result of the goal. Through the DerefMut trait you can use the oneshot::Receiver API to await the final result. Note that it can only be received once.

Methods from Deref<Target = Shared<Receiver<(GoalStatusCode, A::Result)>>>

pub fn peek(&self) -> Option<&<Fut as Future>::Output>

Returns Some containing a reference to this Shared’s output if it has already been computed by a clone or None if it hasn’t been computed yet or this Shared already returned its output from poll.

pub fn downgrade(&self) -> Option<WeakShared<Fut>>

Creates a new WeakShared for this Shared.

Returns None if it has already been polled to completion.

pub fn strong_count(&self) -> Option<usize>

Gets the number of strong pointers to this allocation.

Returns None if it has already been polled to completion.

Safety

This method by itself is safe, but using it correctly requires extra care. Another thread can change the strong count at any time, including potentially between calling this method and acting on the result.

pub fn weak_count(&self) -> Option<usize>

Gets the number of weak pointers to this allocation.

Returns None if it has already been polled to completion.

Safety

This method by itself is safe, but using it correctly requires extra care. Another thread can change the weak count at any time, including potentially between calling this method and acting on the result.

pub fn ptr_hash<H>(&self, state: &mut H)
where H: Hasher,

Hashes the internal state of this Shared in a way that’s compatible with ptr_eq.

pub fn ptr_eq(&self, rhs: &Shared<Fut>) -> bool

Returns true if the two Shareds point to the same future (in a vein similar to Arc::ptr_eq).

Returns false if either Shared has terminated.