WaitSetRunner

Struct WaitSetRunner 

pub struct WaitSetRunner { /* private fields */ }
This is a utility class that executors can use to easily run and manage their wait set.

Implementations

Source

impl WaitSetRunner

pub fn new(worker_options: ExecutorWorkerOptions) -> Self

Create a new WaitSetRunner.

pub fn waitable_sender(&self) -> UnboundedSender<Waitable>

Get the sender that allows users to send new Waitables to this WaitSetRunner.

pub fn payload_task_sender(&self) -> UnboundedSender<PayloadTask>

Get the sender that allows users to send new PayloadTasks to this WaitSetRunner.

pub fn activity_listeners(&self) -> Arc<Mutex<Vec<WeakActivityListener>>>

Get the group of senders that will be triggered each time the wait set is woken up. This is used

pub fn guard_condition(&self) -> &Arc<GuardCondition>

Get the guard condition associated with the wait set of this runner.

pub fn run( self, conditions: WaitSetRunConditions, ) -> Promise<(Self, Result<(), RclrsError>)>

Spawn a thread to run the wait set. You will receive a Promise that will be resolved once the wait set stops spinning.

Note that if the user gives a SpinOptions::until_promise_resolved, the best practice is for your executor runtime to swap that out with a new promise which ensures that the ExecutorWorkerOptions::guard_condition will be triggered after the user-provided promise is resolved.

pub fn run_blocking( &mut self, conditions: WaitSetRunConditions, ) -> Result<(), RclrsError>

Run the wait set on the current thread. This will block the execution of the current thread until the wait set is finished waiting.

Note that if the user gives a SpinOptions::until_promise_resolved, the best practice is for your executor runtime to swap that out with a new promise which ensures that the ExecutorWorkerOptions::guard_condition will be triggered after the user-provided promise is resolved.